@@ -1,4 +1,5 @@
 import time
+from .base import APIObject
 
 
 class WaitableMixin:
@@ -44,7 +45,7 @@ class LaunchableMixin:
             data['job_tags'] = ','.join(tags)
         result = self.api.request(
             'POST', self._path + f"{self.id}/launch/", data)
-        return self._creates.load(result[self._creates._path.strip('/').rstrip('s')], self.api)
+        return APIObject.load_url(result['url'], self.api)
 
     def schedule(self, name, rrule, **kwargs):
         """
